plotLinesBetweenAllTips: Plot lines between coordinates of tips on phylogenies

Description Usage Arguments

View source: R/tanglePlot.R

Description

Function used by tanglePlot()

Usage

1
2
3
4
5
6
7
8
9
plotLinesBetweenAllTips(
  tipLocationsA,
  tipLocationsB,
  col = "black",
  lwd = 1,
  lty = 1,
  onlyIfDifferent = TRUE,
  offsetProp = NULL
)

Arguments

tipLocationsA

a list of coordinates of tips on a phylogenetic tree plot

tipLocationsB

a list of coordinates of tips on a phylogenetic tree plot

col

colour of the lines connecting tips. Defaults to black

lwd

width of the lines connecting tips. Defaults to 1

lty

type of the lines connecting tips. Defaults to 1 (solid)

onlyIfDifferent

a boolean variable, if TRUE only plots lines between tips that are in different locations on the phylogenies, otherwise lines between all tips are plotted. Defaults to TRUE

offsetProp

offset value to displace starts of connecting lines from tips, set as the proportion of plotting window. Defaults to NULL (off)


JosephCrispell/phyloHelpeR documentation built on April 7, 2020, 8:28 a.m.