Function used by tanglePlot()
1 2 3 4 5 6 7 8 9 | plotLinesBetweenAllTips(
tipLocationsA,
tipLocationsB,
col = "black",
lwd = 1,
lty = 1,
onlyIfDifferent = TRUE,
offsetProp = NULL
)
|
tipLocationsA |
a list of coordinates of tips on a phylogenetic tree plot |
tipLocationsB |
a list of coordinates of tips on a phylogenetic tree plot |
col |
colour of the lines connecting tips. Defaults to black |
lwd |
width of the lines connecting tips. Defaults to 1 |
lty |
type of the lines connecting tips. Defaults to 1 (solid) |
onlyIfDifferent |
a boolean variable, if |
offsetProp |
offset value to displace starts of connecting lines from tips, set as the proportion of plotting window. Defaults to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.